========
Nodeshot
========

.. image:: https://travis-ci.org/ninuxorg/nodeshot.png
   :target: https://travis-ci.org/ninuxorg/nodeshot

.. image:: https://coveralls.io/repos/ninuxorg/nodeshot/badge.png
  :target: https://coveralls.io/r/ninuxorg/nodeshot

.. image:: https://landscape.io/github/ninuxorg/nodeshot/master/landscape.png
   :target: https://landscape.io/github/ninuxorg/nodeshot/master
   :alt: Code Health

.. image:: https://requires.io/github/ninuxorg/nodeshot/requirements.png?branch=master
   :target: https://requires.io/github/ninuxorg/nodeshot/requirements/?branch=master
   :alt: Requirements Status

Extensible Django web application for management of community-led georeferenced data.

New version in development. Stay tuned.

Find the documentation (work in progress) here: http://nodeshot.readthedocs.org/en/latest/
